"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = require("axios");
var merge_config_1 = require("./utils/merge_config");
// axios.defaults.timeout = 5000
// axios.defaults.withCredentials = true
// axios.defaults.validateStatus = function (status) {
//   return status >= 200 && status < 599; 
// }
exports.axiosIns = axios_1.default.create({
    timeout: 5000,
    withCredentials: true,
    validateStatus: function (status) { return status >= 200 && status < 599; }
});
var Http = /** @class */ (function () {
    function Http(baseUrl) {
        this.cancelToken = axios_1.default.CancelToken;
        this.source = this.cancelToken.source();
        if (baseUrl) {
            this.baseUrl = baseUrl;
        }
    }
    Http.prototype.request = function (opt) {
        var actualOpt = Object.assign({}, opt);
        var tokenObj = null;
        if (this.baseUrl) {
            actualOpt.baseURL = this.baseUrl;
        }
        try {
            tokenObj = JSON.parse(localStorage.getItem(Http.tokenKey));
        }
        catch (err) {
            console.error(err);
        }
        if (tokenObj) {
            actualOpt.headers = Object.assign({}, tokenObj, opt.headers);
        }
        actualOpt.cancelToken = this.source.token;
        return exports.axiosIns.request(actualOpt);
    };
    Http.prototype.abort = function () {
        this.source.cancel('API abort.');
    };
    Http.prototype.get = function (url, configs) {
        return this.request(__assign({ method: 'get', url: url }, configs));
    };
    Http.prototype.post = function (url, data, configs) {
        return this.request(__assign({ method: 'post', url: url,
            data: data, headers: {
                'Content-type': 'application/x-www-form-urlencoded'
            } }, configs));
    };
    Http.prototype.put = function (url, data, configs) {
        return this.request(__assign({ method: 'put', url: url,
            data: data }, configs));
    };
    Http.prototype.patch = function (url, data, configs) {
        return this.request(__assign({ method: 'patch', url: url,
            data: data }, configs));
    };
    Http.prototype.delete = function (url, configs) {
        return this.request(__assign({ method: 'delete', url: url }, configs));
    };
    Http.setToken = function (authorizationType, authorization) {
        localStorage.setItem(this.tokenKey, JSON.stringify({
            authorizationType: authorizationType,
            authorization: authorization
        }));
    };
    Http.setDefaultConf = function (configs) {
        if (configs === void 0) { configs = {}; }
        exports.axiosIns.defaults = merge_config_1.default(exports.axiosIns.defaults, configs);
    };
    Http.setReqInterceptor = function (resolve, reject) {
        // Add a request interceptor
        exports.axiosIns.interceptors.request.use(function (config) {
            // Do something before request is sent
            resolve && resolve(config);
            return config;
        }, function (error) {
            // Do something with request error
            reject && reject(error);
            return Promise.reject(error);
        });
    };
    Http.setResInterceptor = function (resolve, reject) {
        // Add a response interceptor
        exports.axiosIns.interceptors.response.use(function (response) {
            // Do something with response data
            resolve && resolve(response);
            return response;
        }, function (error) {
            reject && reject(error);
            // Do something with response error
            return Promise.reject(error);
        });
    };
    Http.authorizationType = '';
    Http.tokenKey = 'token';
    return Http;
}());
exports.default = Http;
//# sourceMappingURL=mlz_axios.js.map