(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('axios')) :
    typeof define === 'function' && define.amd ? define(['exports', 'axios'], factory) :
    (global = global || self, factory(global.mlzAxios = {}, global.axios));
}(this, function (exports, axios) { 'use strict';

    axios = axios && axios.hasOwnProperty('default') ? axios['default'] : axios;

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation. All rights reserved.
    Licensed under the Apache License, Version 2.0 (the "License"); you may not use
    this file except in compliance with the License. You may obtain a copy of the
    License at http://www.apache.org/licenses/LICENSE-2.0

    THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
    KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
    WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
    MERCHANTABLITY OR NON-INFRINGEMENT.

    See the Apache Version 2.0 License for specific language governing permissions
    and limitations under the License.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    function isPlainObject(val) {
        var toString = Object.prototype.toString;
        return toString.call(val) === '[object Object]';
    }
    function deepMerge() {
        var objs = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            objs[_i] = arguments[_i];
        }
        var result = Object.create(null);
        objs.forEach(function (obj) {
            if (obj) {
                Object.keys(obj).forEach(function (key) {
                    var val = obj[key];
                    if (isPlainObject(val)) {
                        if (isPlainObject(result[key])) {
                            result[key] = deepMerge(result[key], val);
                        }
                        else {
                            result[key] = deepMerge(val);
                        }
                    }
                    else {
                        result[key] = val;
                    }
                });
            }
        });
        return result;
    }

    var strats = Object.create(null);
    // 默认合并策略
    function defaultStrat(val1, val2) {
        return typeof val2 !== 'undefined' ? val2 : val1;
    }
    function fromVal2Strat(val1, val2) {
        if (typeof val2 !== undefined) {
            return val2;
        }
    }
    function deepMergeStrat(val1, val2) {
        if (isPlainObject(val2)) {
            return deepMerge(val1, val2);
        }
        else if (typeof val2 !== 'undefined') {
            return val2;
        }
        else if (isPlainObject(val1)) {
            return deepMerge(val1);
        }
        else {
            return val1;
        }
    }
    var stratKeysFromVal2 = ['url', 'params', 'data', 'method'];
    stratKeysFromVal2.forEach(function (key) {
        strats[key] = fromVal2Strat;
    });
    var stratKeysDeepMerge = ['headers', 'auth', 'proxy'];
    stratKeysDeepMerge.forEach(function (key) {
        strats[key] = deepMergeStrat;
    });
    function isValidKey(key, obj) {
        return key in obj;
    }
    function mergeConfig(config1, config2) {
        if (!config2) {
            config2 = {};
        }
        var config = Object.create(null);
        for (var key in config2) {
            if (isValidKey(key, config2)) {
                mergeField(key);
            }
        }
        for (var key in config1) {
            if (isValidKey(key, config1)) {
                if (!config2[key]) {
                    mergeField(key);
                }
            }
        }
        function mergeField(key) {
            var strat = strats[key] || defaultStrat;
            config[key] = strat(config1[key], config2[key]);
        }
        return config;
    }

    // axios.defaults.timeout = 5000
    // axios.defaults.withCredentials = true
    // axios.defaults.validateStatus = function (status) {
    //   return status >= 200 && status < 599; 
    // }
    var axiosIns = axios.create({
        timeout: 5000,
        withCredentials: true,
        validateStatus: function (status) { return status >= 200 && status < 599; }
    });
    var Http = /** @class */ (function () {
        function Http(baseUrl) {
            this.cancelToken = axios.CancelToken;
            this.source = this.cancelToken.source();
            if (baseUrl) {
                this.baseUrl = baseUrl;
            }
        }
        Http.prototype.request = function (opt) {
            var actualOpt = Object.assign({}, opt);
            var tokenObj = null;
            if (this.baseUrl) {
                actualOpt.baseURL = this.baseUrl;
            }
            try {
                tokenObj = JSON.parse(localStorage.getItem(Http.tokenKey));
            }
            catch (err) {
                console.error(err);
            }
            if (tokenObj) {
                actualOpt.headers = Object.assign({}, tokenObj, opt.headers);
            }
            actualOpt.cancelToken = this.source.token;
            return axiosIns.request(actualOpt);
        };
        Http.prototype.abort = function () {
            this.source.cancel('API abort.');
        };
        Http.prototype.get = function (url, configs) {
            return this.request(__assign({ method: 'get', url: url }, configs));
        };
        Http.prototype.post = function (url, data, configs) {
            return this.request(__assign({ method: 'post', url: url,
                data: data, headers: {
                    'Content-type': 'application/x-www-form-urlencoded'
                } }, configs));
        };
        Http.prototype.put = function (url, data, configs) {
            return this.request(__assign({ method: 'put', url: url,
                data: data }, configs));
        };
        Http.prototype.patch = function (url, data, configs) {
            return this.request(__assign({ method: 'patch', url: url,
                data: data }, configs));
        };
        Http.prototype.delete = function (url, configs) {
            return this.request(__assign({ method: 'delete', url: url }, configs));
        };
        Http.setToken = function (authorizationType, authorization) {
            localStorage.setItem(this.tokenKey, JSON.stringify({
                authorizationType: authorizationType,
                authorization: authorization
            }));
        };
        Http.setDefaultConf = function (configs) {
            if (configs === void 0) { configs = {}; }
            axiosIns.defaults = mergeConfig(axiosIns.defaults, configs);
        };
        Http.setReqInterceptor = function (resolve, reject) {
            // Add a request interceptor
            axiosIns.interceptors.request.use(function (config) {
                // Do something before request is sent
                resolve && resolve(config);
                return config;
            }, function (error) {
                // Do something with request error
                reject && reject(error);
                return Promise.reject(error);
            });
        };
        Http.setResInterceptor = function (resolve, reject) {
            // Add a response interceptor
            axiosIns.interceptors.response.use(function (response) {
                // Do something with response data
                resolve && resolve(response);
                return response;
            }, function (error) {
                reject && reject(error);
                // Do something with response error
                return Promise.reject(error);
            });
        };
        Http.authorizationType = '';
        Http.tokenKey = 'token';
        return Http;
    }());

    exports.axiosIns = axiosIns;
    exports.default = Http;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=ts-axios.umd.js.map
